import React, { FC } from 'react';
import { VariantProps } from 'class-variance-authority';
import { NumericFormatProps } from 'react-number-format';
import { InputVariants } from './variants';
type BasicInputs = {
    placeholder?: string;
    className?: string;
    label?: string;
    labelClass?: string;
    fieldError?: string | undefined;
};
export type InputProps = BasicInputs & {
    type?: React.HTMLInputTypeAttribute | undefined;
    inputProps?: React.DetailedHTMLProps<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>;
};
export type SearchInputProps = React.DetailedHTMLProps<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement> & {
    isSearching?: boolean;
    onCancel: () => void;
};
export type InputMoneyProps = BasicInputs & NumericFormatProps & {
    inputClass?: string;
};
export type SelectProps = BasicInputs & {
    inputProps?: React.DetailedHTMLProps<React.SelectHTMLAttributes<HTMLSelectElement>, HTMLSelectElement>;
    selectOptions: Record<string, any>[];
    optionsEntries: [string, string];
    disabled?: boolean;
};
export type SwitchProps = {
    className?: string;
    label?: string;
    labelClass?: string;
    fieldError?: string | undefined;
    value?: boolean;
    onChange?: () => void;
    disabled?: boolean;
};
export type CheckBoxProps = {
    className?: string;
    label?: string;
    labelClass?: string;
    fieldError?: string | undefined;
    inputProps?: React.DetailedHTMLProps<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>;
    disabled?: boolean;
};
export type RadioProps = {
    label?: string;
    inputProps?: React.DetailedHTMLProps<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>;
};
export type TextAreaProps = BasicInputs & {
    inputProps?: React.DetailedHTMLProps<React.TextareaHTMLAttributes<HTMLTextAreaElement>, HTMLTextAreaElement>;
};
type ErrorSpan = {
    message?: string;
};
interface InputVariants extends VariantProps<typeof InputVariants> {
}
export declare const InputError: FC<ErrorSpan>;
export declare const InputCs3: FC<InputProps & InputVariants>;
export declare const InputMoneyCs3: FC<InputMoneyProps & InputVariants>;
export declare const SelectCs3: FC<SelectProps & InputVariants>;
export declare const RadioInputCs3: FC<RadioProps>;
export declare const SwitchButtonCs3: FC<SwitchProps>;
export declare const CheckBoxInput: FC<CheckBoxProps>;
export declare const InputSearchCs3: FC<SearchInputProps>;
export declare const TextAreaCs3: FC<TextAreaProps & InputVariants>;
export {};
